/** \file highway_A_loopback.c
 * highway_A_loopback.c
 *
 * This is an application patterned after Epygi's testtsiapp.c that is intended
 * to cross connect the	RX and TX of PCM highway A to enable a hello world
 * hotline demo.
 *
 * Copyright (c) 2008, Zarlink Semiconductor Inc.
 * All rights reserved
 *
 * This software is the property of Zarlink Semiconductor , Inc. Please refer to the
 * Non Disclosure Agreement (NDA) that you have signed for more information
 * on legal obligations in using, modifying or distributing this file.
 */

#include <sys/types.h>
#include <unistd.h>

#include "ttsi1k16tapi.h"

RxTxHighwayStr					highway_mode;
TimeSlotConectionStoreMemory	ts_struct;
HighwayStr						highway_connect;

int HighwayALoopBack(void)
{
	int retval = 0;

	if(ttsi1k16tInit() != 0)
	{
		return -1;
	}

	HighwaysReInit();

	/* ----------------6/6/2004 4:50PM------------------
	 *  Set the Highway Parameters for PCM Highway A here.  Remember this api
	 * is done from the perspective of the TDM cross switch.  Therefore the
	 * transmit highway A to the connectors will actually hook up to the receive
	 * highway coming out of the DUT on the line module.  In the highway data
	 * rate defines DARA = DATA by the way, but the header definitions even
	 * say DARA .. go figure
	 * --------------------------------------------------*/


	/*-----------------6/10/2004 2:45PM-----------------
	 * New settings with no offset
	 * --------------------------------------------------*/
	highway_mode.HighwayTimeSlotOffset = 0x00;
	highway_mode.HighwayDataRate = TSI_HIGHWAY_DATA_RATE_8MB;
	highway_mode.HighwayBitOffset = 0x0;
	highway_mode.HighwayNum = HIGHWAY_LEGERITY_CONNECTORS_A;
	highway_mode.RxTxMode = TRANSMIT_HIGHWAY;

	SetHighwayMode(highway_mode);

	highway_mode.HighwayTimeSlotOffset = 0x00;
	highway_mode.HighwayDataRate = TSI_HIGHWAY_DATA_RATE_8MB;
	highway_mode.HighwayBitOffset = 0x0;
	highway_mode.HighwayNum = HIGHWAY_LEGERITY_CONNECTORS_A;
	highway_mode.RxTxMode = RECEIVE_HIGHWAY;

	SetHighwayMode(highway_mode);


	  /*-----------------6/6/2004 4:57PM------------------
	   * Now set the time slot information.
	   * TimeSlotNum is the transmit (TDM side)  that connects to the DUT receive highway
	   * ReceiveTimeSlotNum is the Receive (TDM side) that connects to the DUT transmit higway
	   * ReceiveHighwayNum indicates which incoming receive highway will be the source for
	   * the transmit highway data for that time slot.  In our case we want
	   * HIGHWAY_LEGERITY_CONNECTORS_A which has been defined equal to highway number 0 in the
	   * driver header already
	   *
	   * In order to set up a loopback to the DUT Transmit to Receive between Channel 1 and
	   * Channel 2 we would cross connect as follows:
	   *
	   *								TDM RX 							TDM TX
	   *								-------							-------
	   *	   	 	Chan1				XTS =0							RTS = 1
	   *			Chan 2				XTS = 1							RTS = 0
	   * --------------------------------------------------*/

	/*-----------------6/6/2004 5:29PM------------------
	 *  First set up channel 1.  */
	ts_struct.HighwayNum = HIGHWAY_LEGERITY_CONNECTORS_A;
	ts_struct.TimeSlotNum = 1;        /* This is the outgoing transmit timeslot. */
	ts_struct.ReceiveTimeslotNum = 0; /* This is the incoming data timeslot from the DUT. */
	ts_struct.ReceiveHighwayNum = HIGHWAY_LEGERITY_CONNECTORS_A; /* The data comes from PCM highway A */
	ts_struct.TimeSlotDataSelectMode = 0;    /* This is low latency mode.  The other option is frame-integrity mode.*/

	/*-----------------6/6/2004 5:36PM------------------
	 * Write the changes to the ts_struct structure to the TDM switch
	 * --------------------------------------------------*/
	ChangeTimeSlotMode(ts_struct);

	/*-----------------6/6/2004 5:37PM------------------
	 * Now set up and modify the TDM parameters for Channel 2.
	 * --------------------------------------------------*/
	ts_struct.HighwayNum = HIGHWAY_LEGERITY_CONNECTORS_A;
	ts_struct.TimeSlotNum = 0;        /* This is the outgoing transmit timeslot. */
	ts_struct.ReceiveTimeslotNum = 1; /* This is the incoming data timeslot from the DUT. */
	ts_struct.ReceiveHighwayNum = HIGHWAY_LEGERITY_CONNECTORS_A; /* The data comes from PCM highway A */
	ts_struct.TimeSlotDataSelectMode = 0;    /* This is low latency mode.  The other option is frame-integrity mode.*/

	ChangeTimeSlotMode(ts_struct);

    return retval;
}


